from setuptools import setup, find_packages

with open("README.md", "r", encoding="utf-8") as f:
    long_description = f.read()

setup(
    name="repurposcan",
    version="0.1.1",
    packages=find_packages(),
    include_package_data=True,

    install_requires=[
        "numpy<2",
        "pandas",
        "scikit-learn",
        "xgboost",
        "rdkit-pypi",
        "joblib"
    ],

    author="Ayush Laware",
    description="Drug-target binding affinity prediction using XGBoost",


    long_description=long_description,
    long_description_content_type="text/markdown",
)
